# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).



## [1.1.0] - 2018-08-25
### Changed
- Refactored as Python package.



## [0.0.1] - 2017-08-06 - First release



[1.1.0] https://github.com/ggirelli/fish-prode/releases/tag/v1.1.0  
[0.0.1] https://github.com/ggirelli/fish-prode/releases/tag/v0.0.1  
